/***************************************************************************
 *   Copyright (C) 2002 by Christopher TenHarmsel                          *
 *   tenharmsel@users.sourceforge.net                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include "cardprofile.h"
#include <kconfig.h>
#include <kglobal.h>

CardProfile::CardProfile(){
		_config = KGlobal::config();
}

CardProfile::CardProfile( const CardProfile &oldProfile ){
	_SSID = oldProfile.SSID();
	_WEPKey = oldProfile.WEPKey();
	_Mode = oldProfile.mode();
	_enableWEP = oldProfile.enableWEP();
	_name = oldProfile.name();
	_config = KGlobal::config();
}

CardProfile::CardProfile( const QString &ssid, bool wepEnabled, const QString &wepKey,
                          int mode ){
	_SSID = ssid;
	_name = ssid;
	_WEPKey = wepKey;
	_Mode = mode;
	_enableWEP = wepEnabled;
	_config = KGlobal::config();
}

CardProfile::CardProfile( const QString &name, const QString &ssid, bool wepEnabled,
                          const QString &wepKey, int mode){
	_name = name;
	_SSID = ssid;
	_WEPKey = wepKey;
	_Mode = mode;
	_enableWEP = wepEnabled;
	_config = KGlobal::config();
}

CardProfile::~CardProfile(){
}

void CardProfile::setSSID( const QString &newSSID ){
	_SSID = newSSID;
}

void CardProfile::setWEPKey( const QString &newWEPKey ){
	_WEPKey = newWEPKey;
}

void CardProfile::setMode( int newMode ){
	if( newMode == MODE_ADHOC || newMode == MODE_INFRASTRUCTURE ){
	    _Mode = newMode;
	}
}

void CardProfile::setWEPEnabled( bool wepEnabled ){
	_enableWEP = wepEnabled;
}

void CardProfile::setName( const QString &name ){
	_name = name;
}

void CardProfile::writeConfig(){
	// Set the group to this config's name
	_config->setGroup(_name);
	_config->writeEntry("SSID", _SSID);
	_config->writeEntry("EnableWEP", _enableWEP);
	_config->writeEntry("WEPKey", _WEPKey);
	_config->writeEntry("Mode", _Mode);
}

void CardProfile::loadConfig( const QString &name ){
	if(name == ""){
		return;
	}
	// Check to see if the config has a config named this
	if(_config->hasGroup(name)){
		_name = name;
		// Set the group to read from
		_config->setGroup(name);
		// Read the properties from the config and save them
		_SSID = _config->readEntry("SSID");
		_enableWEP = _config->readBoolEntry("EnableWEP");
		_WEPKey = _config->readEntry("WEPKey");
		_Mode = _config->readNumEntry("Mode");
	}
}

CardProfile& CardProfile::operator=(const CardProfile& copyCard){
	// Gracefully handle self assignment
	if(this == &copyCard){
		return *this;
	}
	// Copy the values over
	_SSID = copyCard.SSID();
	_WEPKey = copyCard.WEPKey();
	_Mode = copyCard.mode();
	_enableWEP = copyCard.enableWEP();
	_name = copyCard.name();
	return *this;
}

bool operator==( const CardProfile& a, const CardProfile& b){
	return (a.name() == b.name()) && (a.SSID() == b.SSID()) &&
		(a.WEPKey() == b.WEPKey()) && (a.mode() == b.mode()) &&
		(a.enableWEP() == b.enableWEP());
}


		

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 4
 * indent-tabs-mode: t
 * End:
 */
