/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include "cardprofilecontroller.h"
#include <kglobal.h>
#include <kconfig.h>
#include <qstringlist.h>

CardProfileController::CardProfileController(){
	// Get the config object
	mConfig = KGlobal::config();

	// Instantiate the profile names list
	mProfileNames = new QStringList(mConfig->readListEntry("Profile Names"));

	// Set autodelete on the profile dict
	mCardProfiles.setAutoDelete(true);

	// Check to see if we found any profiles
	if(mProfileNames->size() < 1){
		// Add an empty profile to the dict
		mCardProfiles.insert("Profile One",
												 new CardProfile("Profile One", "", false,
																				 "", CardProfile::MODE_INFRASTRUCTURE));
		// Keep track of it's name
		mProfileNames->append("Profile One");

		// Tell it to write itself out
		mCardProfiles["Profile One"]->writeConfig();

	} else {
		// We've found some stored profiles, so get them
		for(QStringList::Iterator it = mProfileNames->begin();
				it != mProfileNames->end(); it++){
			mCardProfiles.insert(*it, new CardProfile());
			// Tell the new profile to load itself from the config
			mCardProfiles[*it]->loadConfig(*it);
		}
	}
}

QStringList CardProfileController::profileNames(){
	return QStringList(*mProfileNames);
}

CardProfile* CardProfileController::getProfile(QString name){
	if(mProfileNames->contains(name) == 0){
		return 0L;
	} else {
		return mCardProfiles[name];
	}
}

bool CardProfileController::createProfile(const QString &name) {
	if(mProfileNames->contains(name) != 0){
		return false;
	} else {
		mCardProfiles.insert(name, new CardProfile("", "", false, "", CardProfile::MODE_INFRASTRUCTURE));
		mProfileNames->append(name);
		mCardProfiles[name]->writeConfig();
		return true;
	}
}

void CardProfileController::saveProfiles(){
	// Get an iterator on the dict
	for(QStringList::Iterator it = mProfileNames->begin();
			it != mProfileNames->end(); it++){
		// Tell it to save itself
		mCardProfiles[*it]->writeConfig();
	}
	// I guess passing a null switches back to the default group
	mConfig->setGroup(0L);
	// Write out the profile names to the config
	mConfig->writeEntry("Profile Names", *mProfileNames);
}

CardProfileController::~CardProfileController(){
	// Save all the profile information
	saveProfiles();
}

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
