/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef CARDPROFILECONTROLLER_H
#define CARDPROFILECONTROLLER_H

#include "cardprofile.h"
#include <qdict.h>
#include <qstring.h>
#include <qstringlist.h>

// Forward Declarations (included in .cpp file)
class QStringList;

class CardProfileController {
public:
	/**
	 * Constructor
	 * @param numberOfProfiles The number of profiles to manage
	 */
	CardProfileController();
	/** Destructor */
	~CardProfileController();

	/**
	 * Accessor method for the names of profiles
	 * @return A list of names of profiles
	 */
	QStringList profileNames();

	/**
	 * Accessor method for a single profile, keep
	 * in mind that this is a pointer to the profile
	 * itself, and so any updates will affect it
	 * @param name The name of the profile you want to get
	 * @return A Pointer to the requested CardProfile, null
	 * if named profile does not exist
	 */
	CardProfile* getProfile(QString name);

	/**
	 * This method adds a new/empty card profile
	 * @param name The name of the new card profile to add.
	 * @return A boolean indicating whether or not the profile could
	 * be created.  FALSE usually indicates that a profile with
	 * the requested name already exists.
	 */
	bool createProfile(const QString &name);

	/**
	 * Method to save all profiles
	 */
	void saveProfiles();

protected:
	QDict<CardProfile> mCardProfiles;
	KConfig *mConfig;
	QStringList *mProfileNames;
};

#endif

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
