/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include <kglobal.h>
#include <klocale.h>
#include <kdebug.h>

#include "kifi.h"
#include "interfacemonitor.h"

KiFi::KiFi() : KApplication(true, true)
{
	kdDebug() << k_funcinfo << endl;
	// Get our configuration object
	ksConfig = sessionConfig();

	kdDebug() << "Creating config window" << endl;

	kdDebug() << "Creating interface monitor" << endl;
	// Create the interface monitor
	_interfaceMonitor = new InterfaceMonitor( this );

	kdDebug() << "Connecting signals from interface monitor" << endl;
	// Listen for new NICs
	connect( _interfaceMonitor, SIGNAL( interfaceFound( QString ) ),
					 this, SLOT( slotNewWirelessInterface( QString ) ) );
	// Listen for lost NICs
	connect( _interfaceMonitor, SIGNAL( interfaceLost( QString ) ),
					 this, SLOT( slotLostWirelessInterface( QString ) ) );

	// Tell the interface monitor to start monitoring
	kdDebug() << "Asking the interface monitor to start monitoring" << endl;
	_interfaceMonitor->start();

	// Tell the list of KifiSystrayControllers to manage it's contents
	_systrayControllers.setAutoDelete( true );
	kdDebug() << "KiFi constructor finished" << endl;

}

KiFi::~KiFi()
{
	// Clean up after ourselves
	delete _interfaceMonitor;
}

void KiFi::slotHandleQuit()
{
	kdDebug() << k_funcinfo << "Exiting KiFi" << endl;
	quit();
}

void KiFi::slotShowPreferences()
{
	kdDebug() << k_funcinfo << endl;
}

void KiFi::slotNewWirelessInterface( QString interface )
{
	// Add a new KifiSystrayController
	KiFiSystrayController *newThing =
		new KiFiSystrayController( interface );

	_systrayControllers.insert( interface, newThing );

	// Connect the quit signal from the new controller to
	// the our quit slot
	connect( newThing, SIGNAL( quitSelected() ),
					 this,  SLOT( quit() ) );
}

void KiFi::slotLostWirelessInterface( QString interface )
{
	// Remove the indicated interface
	_systrayControllers.remove( interface );
}

#include "kifi.moc"

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
