/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include "kifisystemtray.h"
#include "wirelessinfoengine.h"

#include <kdebug.h>
#include <kconfig.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kpopupmenu.h>

#include <qtimer.h>
#include <qtooltip.h>

KiFiSystemTray::KiFiSystemTray( QWidget* parent, const char* name)
	: KSystemTray( parent, name )
{
	kdDebug() << "Creating KiFiSystemTray" << endl;

	// Get the icon loader
	_iconLoader = KGlobal::iconLoader();
	// Load the icons
	_signalNone = _iconLoader->loadIcon("signal_none", KIcon::User);
	_signalLow = _iconLoader->loadIcon("signal_low", KIcon::User);
	_signalMedium = _iconLoader->loadIcon("signal_medium", KIcon::User);
	_signalGood = _iconLoader->loadIcon("signal_good", KIcon::User);

	// Set the pixmap
	setPixmap( _signalNone );
	QToolTip::add( this, i18n("No Signal") );

	// Initialize the actions
	initActions();
}

void KiFiSystemTray::initActions()
{
	contextMenu()->insertItem(
		_iconLoader->loadIcon("configure", KIcon::Small),
		i18n("Preferences"),
		this, SLOT(slotPreferencesSelected()));

	// Create an entry to toggle scanning
	_scanningToggleId = contextMenu()->insertItem(
		i18n("Start Scanning"),
		this, SLOT(slotToggleScanning()));


	kdDebug() << "Created scanning toggle, id: " << _scanningToggleId << endl;

// Start the thing unchecked
	contextMenu()->setItemChecked(_scanningToggleId, false);
	kdDebug() << "Is item checked? " << contextMenu()->isItemChecked( _scanningToggleId ) << endl;

}

/*!
    \fn KiFiSystemTray::slotToggleScanning()
 */
void KiFiSystemTray::slotToggleScanning()
{
	kdDebug() << "Scanning menu item clicked" << endl;
	bool toggled = contextMenu()->isItemChecked(_scanningToggleId);
	kdDebug() << "Is item checked? " << toggled << endl;
	if( toggled ){
		kdDebug() << "Turning off scanning" << endl;
		// It was toggled, now it's not
		contextMenu()->changeItem(i18n("Start Scanning"), _scanningToggleId);
		contextMenu()->setItemChecked(_scanningToggleId, false);
		emit stopScanningSelected();
	} else {
		kdDebug() << "Turning on scanning" << endl;
		// It wasn't toggled, now it is
		contextMenu()->changeItem(i18n("Stop Scanning"), _scanningToggleId);
		//contextMenu()->changeItem(_iconLoader->loadIcon("scanning_stop", KIcon::User),
		//		_scanningToggleId);
		contextMenu()->setItemChecked(_scanningToggleId, true);
		emit startScanningSelected();
	}

	// Set it to the opposite
	contextMenu()->setItemChecked(_scanningToggleId, !toggled);
}

KiFiSystemTray::~KiFiSystemTray()
{
	// Nothing
}

void KiFiSystemTray::mousePressEvent( QMouseEvent *e )
{
	kdDebug() << k_funcinfo << endl;
	KSystemTray::mousePressEvent(e);

	if ( e->button() == Qt::LeftButton )
	{
		kdDebug() << k_funcinfo << "Show info"<< endl;
		emit infoSelected();
	}
}

void KiFiSystemTray::mouseDoubleClickEvent( QMouseEvent *me )
{
	// Do this to avoid warnings
	me = me;
	kdDebug() << k_funcinfo << endl;
}

void KiFiSystemTray::setSignalStrengthDisplay( int quality, QString ssid )
{
	// Figure out which image to display depending on the level
	if ( quality <= 0 ) {
		kdDebug() << "Setting signal to none" << endl;
		setPixmap( _signalNone );
	} else if( quality < 20 ) {
		kdDebug() << "Setting signal to low" << endl;
		setPixmap( _signalLow );
	} else if( quality < 70 ) {
		kdDebug() << "Setting signal to medium" << endl;
		setPixmap( _signalMedium );
	} else {
		kdDebug() << "Setting signal to good" << endl;
		setPixmap( _signalGood );
	}

	QString toolTipText = i18n("Signal Strength: %1\n").arg( quality ) +
		i18n("SSID: %1").arg( ssid );

	// Remove the current tool tip
	QToolTip::remove(this);
	QToolTip::add( this, toolTipText );
}

void KiFiSystemTray::slotPreferencesSelected()
{
	emit preferencesSelected();
}

#include "kifisystemtray.moc"

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */


