/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef KIFISYSTEMTRAY_H
#define KIFISYSTEMTRAY_H

#include <ksystemtray.h>
#include <qpixmap.h>

class KPopupMenu;
class KIconLoader;
class QPoint;
class QMouseEvent;

/**
 * This is KiFi's system tray icon
 * @author Chris TenHarmsel <chris@staticmethod.net>
 */

class KiFiSystemTray : public KSystemTray
{
	Q_OBJECT

public:
	/**
	 * Constructor
	 */
	KiFiSystemTray( QWidget* parent = 0, const char* name = 0 );

	/**
	 * Destructor
	 */
	virtual ~KiFiSystemTray();

	/**
	 * Method to set the displayed signal strength
	 * @param strength Quality of the wireless link (0-100)
	 */
	void setSignalStrengthDisplay( int quality, QString ssid );

protected:
	virtual void mousePressEvent( QMouseEvent *e );
	virtual void mouseDoubleClickEvent( QMouseEvent *me );

signals:
	/**
	 * Emitted when the user selects 'Preferences'
	 */
	void preferencesSelected();

	/** Signal when the user wants to start scanning */
	void startScanningSelected();

	/** Signal when the user wants to stop scanning */
	void stopScanningSelected();

	/**
	 * Emitted when the user selects info window
	 */
	void infoSelected();

private:
	QPixmap _signalNone;
	QPixmap _signalLow;
	QPixmap _signalMedium;
	QPixmap _signalGood;
	KIconLoader *_iconLoader;
	int _updateInterval;
	int _scanningToggleId;

	/**
	 * Initializes the actions for the class
	 */
	void initActions();

private slots:

	/**
	 * This slot is called when the user selects 'Preferences'
	 * from the popup menu
	 */
	void slotPreferencesSelected();

protected slots:
    void slotToggleScanning();
};

#endif

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */

