/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef _KIFISYSTRAYCONTROLLER_H_
#define _KIFISYSTRAYCONTROLLER_H_

#include <qobject.h>
#include <qstring.h>
#include <qmap.h>

#include "wirelessnetworkinfo.h"

class KiFiSystemTray;
class KiFiNetworkChooserDialog;
class WirelessInfoEngine;
class WirelessNetworkScanner;
class KPassivePopup;
class QTimer;
class QFrame;

/**
 * This class represents an item in the system tray, which in turn
 * represents one wireless interface
 */
class KiFiSystrayController : public QObject
{
	Q_OBJECT
public:
	/**
	 * Constructor
	 * @param interface The interface that this class represents
	 * @param parent The parent QObject
	 * @param name The name of this object
	 */
	KiFiSystrayController( QString interface,
												 QObject *parent = 0,
												 const char* name = 0 );

	/** Destructor */
	virtual ~KiFiSystrayController();

public slots:
	/**
	 * This slot shows the detailed information window
	 */
	void slotShowInformationWindow();

signals:
	/**
	 * This signal is emitted whenever the user has chosen the
	 * "Quit" option from the context menu of the system tray
	 * icon managed by this controller
	 */
	void quitSelected();

	/**
	 * This signal is emitted when the known networks for the
	 * interface monitored by this system tray controller
	 * have changed in some way
	 */
	void knownNetworksUpdated();

protected slots:
	/**
	 * This slot handles the scanner finding a new network
	 */
	void slotNetworkFound( WirelessNetworkInfo &info);

	/**
	 * This slot handles the scanner finding a new network
	 */
	void slotNetworkUpdated( WirelessNetworkInfo &info);

	/**
	 * This slot handles the scanner finding a new network
	 */
	void slotNetworkLost( WirelessNetworkInfo &info);

	/**
	 * This slot handles the info timer events, it updates the
	 * signal stats displayed in the system tray
	 */
	void slotInfoTimerHandler();

	/**
	 * This slot handles the user choosing to start scanning
	 * from the drop down menu in the system tray
	 */
	void slotStartScanning();

	/**
	 * This slot handles the user choosing to stop scanning
	 * from the drop down menu in the system tray
	 */
	void slotStopScanning();

	/**
	 * This slot is for handling the quit signal from the
	 * system tray that results from the user selecting "Quit"
	 * from the context menu
	 */
	void slotHandleQuit();

	/**
	 * This slot takes the currently selected network (if any)
	 * and attempts to associate with it.
	 */
	void slotUseSelectedNetwork(const QString &);

	/**
	 * This slot closes the network chooser dialog
	 */
	void slotCloseNetworkChooser();
	void slotUpdateNetworkInfoDetails(const QString &);

protected:
	/**
	 * This method initializes all of the signal/slot connections
	 * that this class uses.
	 */
	void initConnections();

	/** Timer for running the wireless info engine */
	QTimer *_infoTimer;

	/** The system tray (View) */
	KiFiSystemTray *_sysTray;
	/** The wireless info engine (Model) */
	WirelessInfoEngine *_engine;
	/** The interface we're representing */
	QString _interfaceName;
	/** Scanner for this interface, looks for available networks */
	WirelessNetworkScanner *_scanner;

	/** Widget to popup when icon is single clicked */
	KiFiNetworkChooserDialog *_chooserDialog;

	/** Frame to hold the popup widget */
	QFrame *_popupFrame;

	/** Boolean indicating whether or not we're currently scanning */
	bool _currentlyScanning;

	/** Passive popup used for showing scanning info */
	KPassivePopup *_infoPopup;

	/** Map of the networks we know about via our scanner */
	QMap<QString, WirelessNetworkInfo> _knownNetworks;
};

#endif

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
