/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Micah Alles <micah@atomicobject.com>
		Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include "kifinetworkchooserdialog.h"

#include <qpushbutton.h>
#include <qlineedit.h>
#include <qprogressbar.h>
#include <klistbox.h>
#include <kdebug.h>

KiFiNetworkChooserDialog::KiFiNetworkChooserDialog(
		QWidget* parent, const char* name)
	  : NetworkChooserBase(parent, name)
{
	// Nothing yet
	initConnections();
}

void KiFiNetworkChooserDialog::initConnections()
{
	// Connect the signals to slots
	connect( _useButton, SIGNAL( clicked() ),
			this, SLOT( useClickedHandler() ) );
	connect( _cancelButton, SIGNAL( clicked() ),
			this, SLOT( cancelClickedHandler() ) );
	connect( _networksListBox, SIGNAL(highlighted(const QString& )),
			this, SLOT(slotListItemSelected(const QString& )));
}

KiFiNetworkChooserDialog::~KiFiNetworkChooserDialog()
{
}

void KiFiNetworkChooserDialog::useClickedHandler()
{
	emit useNetwork(_networksListBox->currentText());
}

void KiFiNetworkChooserDialog::cancelClickedHandler()
{
	// Emit our own signal
	kdDebug() << "KiFiNetworkChooserDialog::cancelClickedHandler" << endl;
	emit cancelSelected();
}

/*!
    \fn KiFiNetworkChooserDialog::showDetailedInfo( WirelessNetworkInfo &)
 */
void KiFiNetworkChooserDialog::showDetailedInfo( WirelessNetworkInfo &networkInfo)
{
	kdDebug() << "KiFiNetworkChooserDialog::showDetailedInfo(): ENTER" << endl;
	_lneAddress->setText( networkInfo.getAddress() );
	networkInfo.getWepRequired() ? _lneWep->setText( "Yes" ) : _lneWep->setText( "No" );
	_prgSignal->setProgress( networkInfo.getSignalStrength() * 2, 100);
	_lneChannel->setText( QString::number( networkInfo.getChannel() ) );
	_lneFrequency->setText( networkInfo.getFrequency() );
	_lbxBitrates->clear();
	_lbxBitrates->insertStringList( networkInfo.getSupportedRates() );
}

/*!
    \fn KiFiNetworkChooserDialog::slotListItemSelected(QString &)
 */
void KiFiNetworkChooserDialog::slotListItemSelected(const QString &text)
{
	// Emit a signal indicating that something has been highlighted
	emit networkHighlighted( text );
}

/*!
    \fn KiFiNetworkChooserDialog::addNetwork(QString &network)
 */
void KiFiNetworkChooserDialog::addNetwork(const QString &network)
{
	kdDebug() << "KiFiNetworkChooserDialog::addNetwork(): ENTER" << endl;
	// Find out if it's already in the list
	QListBoxItem *item = _networksListBox->findItem( network );
	if( !item ) {
		kdDebug() << "Adding network [" << network << "] to list" << endl;
		// If it's not in the list, add it
		_networksListBox->insertItem( network );
	}
}

/*!
    \fn KiFiNetworkChooserDialog::removeNetwork(QString &network)
 */
void KiFiNetworkChooserDialog::removeNetwork(const QString &network)
{
	kdDebug() << "KiFiNetworkChooserDialog::removeNetwork(): ENTER" << endl;
	QListBoxItem *item = _networksListBox->findItem( network );
	if( item ) {

		int index = _networksListBox->index( item );
		_networksListBox->removeItem( index );
	}
}

/*!
    \fn KiFiNetworkChooserDialog::getSelectedItem()
 */
QString KiFiNetworkChooserDialog::getSelectedItem()
{
	QListBoxItem *item = _networksListBox->selectedItem();
	if(item){
		return item->text();
	} else {
		return QString::null;
	}
}

#include "kifinetworkchooserdialog.moc"

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */


