/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Micah Alles <micah@atomicobject.com>
		Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef KIFINETWORKCHOOSERDIALOG_H
#define KIFINETWORKCHOOSERDIALOG_H

#include "networkchooserbase.h"
#include "../wirelessnetworkinfo.h"

#include <qstring.h>
#include <qguardedptr.h>

/**
 * Dialog allowing user to associate with a list of networks.
 */
class KiFiNetworkChooserDialog : public NetworkChooserBase
{
	Q_OBJECT
public:
	/** Constructor, with no list */
	KiFiNetworkChooserDialog(QWidget* parent = 0, const char* name = 0);

	/**
	 * Destructor
	 */
	virtual ~KiFiNetworkChooserDialog();

	void addNetwork(const QString &network);
	void removeNetwork(const QString &network);
	QString getSelectedItem();
	void showDetailedInfo( WirelessNetworkInfo &);

signals:
	/**
	 * This signal is emited when the user clicks on the Cancel
	 * button
	 */
	void cancelSelected();
	/**
	 * This signal is emitted when the user has chosen a network
	 * and clicks on the Use button
	 */
	void useNetwork(const QString &);

	/**
	 * This signal is emitted when a network name is highlighted
	 */
	void networkHighlighted( const QString & );

protected slots:
	/**
	 * Slot to handle clicking on Use
	 */
	void useClickedHandler();

	/**
	 * Slot to handle clicking on the Cancel button
	 */
	void cancelClickedHandler();

	/**
	 * This slot internally handles an item being selected in the list
	 */
	void slotListItemSelected(const QString &);

protected:
	/**
	 * Initializes the internal connections used by this class
	 */
	void initConnections();

};

#endif

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
