/*
    KiFi, KDE Wireless Manager
    Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

    KiFi, (c) 2004 by the KiFi developers

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include "wirelessinfoengine.h"

#include <qcstring.h>
#include <kdebug.h>

/* Just FYI */
/* Modes of operation */
// #define IW_MODE_AUTO    0       /* Let the driver decides */
// #define IW_MODE_ADHOC   1       /* Single cell network */
// #define IW_MODE_INFRA   2       /* Multi cell network, roaming, ... */
// #define IW_MODE_MASTER  3       /* Synchronisation master or Access Point */
// #define IW_MODE_REPEAT  4       /* Wireless Repeater (forwarder) */
// #define IW_MODE_SECOND  5       /* Secondary master/repeater (backup) */


WirelessInfoEngine::WirelessInfoEngine(
	QString interface, QObject *parent, const char *name)
  : QObject(parent, name),
		_interfaceName( interface )
{
	/* Set up the communications socket first */
	_socket = iw_sockets_open();
	/* Set up the stats struct */
	_stats = new iwstats;
}


WirelessInfoEngine::~WirelessInfoEngine()
{
	delete _stats;
}

int WirelessInfoEngine::getSignalQuality()
{
	int retval;
	updateSignalStats() ? retval = (int)_stats->qual.qual : retval = -1;
	return retval;
}

int WirelessInfoEngine::getSignalLevel()
{
	int retval;
	updateSignalStats() ? retval = (int)_stats->qual.level : retval = -1;
	return retval;
}

int WirelessInfoEngine::getSignalNoise()
{
	int retval;
	updateSignalStats() ? retval = (int)_stats->qual.noise : retval = -1;
	return retval;
}

bool WirelessInfoEngine::updateInfo(){
	/* Create a new wireless_config struct to hold info we get back from the driver */
	wireless_config *config = new wireless_config;
	/* Get the info */
	/* Copy the interface name into a char* */
	char ifname[256];
	qstrncpy(ifname, _interfaceName.latin1(), 256);

	if(iw_get_basic_config(_socket, ifname, config) != -1){
		if(config->has_mode == 1){
			switch(config->mode){
				case IW_MODE_AUTO: _mode = Auto; break;
				case IW_MODE_ADHOC: _mode = AdHoc; break;
				case IW_MODE_INFRA: _mode = Infra; break;
				default: _mode = Unknown;
			}
		} else {
			_mode = Unknown;
		}

		if(config->has_key == 1){
			_wepEnabled = true;
			_wepKey = (char*)config->key;
		} else {
			_wepEnabled = false;
			_wepKey = "";
		}

		if(config->has_essid == 1){
			_ssid = config->essid;
		} else {
			_ssid = "";
		}
		delete config;
		return true;
	} else {
		delete config;
		return false;
	}
}

QString WirelessInfoEngine::getSSID(){
	return _ssid;
}

bool WirelessInfoEngine::wepEnabled(){
	return _wepEnabled;
}

// bool WirelessInfoEngine::commitInfo(){
// 	wireless_config *config = new wireless_config;

// 	/* SET UP CHAR*S TO HANDLE C FUNCTIONS */
// 	/* Copy the interface name into a char* */
// 	char ifname[256];
// 	qstrncpy(ifname, interfaceName.latin1(), 256);

// 	// TODO make this use the method in the class
// 	/* Routine to convert QString into unsigned char */
// 	const char *tempString = _wepKey.latin1();
// 	unsigned char unsignedWepKey[IW_ENCODING_TOKEN_MAX];  //That size is defined in wireless.h I believe
// 	int length;
// 	if(_wepKey.length() < IW_ENCODING_TOKEN_MAX){
// 		length = _wepKey.length();
// 	} else {
// 		length = IW_ENCODING_TOKEN_MAX;
// 	}
// 	for( int i = 0; i < length - 1; i++ ){
// 		unsignedWepKey[i] = (unsigned char)tempString[i];
// 	}
// 	unsignedWepKey[IW_ENCODING_TOKEN_MAX] = '\0';
// 	/* End of routine */

// 	/* Set the name of the interface */
// 	qstrncpy(config->name, ifname, sizeof(config->name));

// 	/* Not using either of these right now */
// 	config->has_nwid = 0;
// 	config->has_freq = 0;

// 	/* Set the WEP properties */
// 	if(_wepEnabled){
// 		config->has_key = 1;
// 		config->key_size = _wepKey.length() * sizeof(char);
// 		config->key_flags = IW_ENCODE_ENABLED;
// 		// TODO
// 		qStringToUChar( _wepKey, config->key, sizeof(config->key)/sizeof(unsigned char) );

// 	} else {
// 		config->has_key = 0;
// 		config->key_flags = IW_ENCODE_DISABLED;
// 	}

// 	/* Set the SSID */
// 	config->has_essid = 1;
// 	config->essid_on = 1;
// 	qstrncpy(config->essid, _ssid.latin1(), sizeof(config->key)/sizeof(char) );

// 	/* Set the mode */
// 	config->has_mode = 1;
// 	switch(_mode){
// 		case AdHoc: config->mode = IW_MODE_ADHOC; break;
// 		case Infra: config->mode = IW_MODE_INFRA; break;
// 		case Auto: default: config->mode = IW_MODE_AUTO;
// 	}

// 	/* Set the changes */
// 	if(iw_set_basic_config(_socket, ifname, config) != -1){
// 		/* update the local information */
// 		updateInfo();
// 		return true;
// 	} else {
// 		return false;
// 	}
// }

QString WirelessInfoEngine::getWEPKey(){
	return _wepKey;
}

int WirelessInfoEngine::getMode(){
	return _mode;
}

bool WirelessInfoEngine::updateSignalStats()
{
    char name[10];
    int retval;
    qstrncpy(name, _interfaceName.latin1(), 10);
    if((retval = iw_get_stats( _socket, name, _stats, NULL, false )) == -1) {
			kdDebug() << "[WirelessInfoEngine] Error updating statistics on "
								<< _interfaceName << ": " << retval << endl;
			return false;
    } else {
			return true;
    }
}

void WirelessInfoEngine::qStringToUChar(QString string, unsigned char * uCharArray, int size)
{
    int len = string.length();
    const char *qsc = string.latin1();
    /**
     * if the length of the string is longer than the number
     * of spots in the array, set the number of chars to copy
     * to one less than the number of spots in the array, so
     * that there's room for the null char
     */
    if( len >= size ){
	len = size - 1;
    }

    for (int i=0; i<len; i++) {
	uCharArray[i] = (unsigned char)qsc[i];
    }
    // Write the last char: the null
    uCharArray[len] = '\0';
}


#include "wirelessinfoengine.moc"
