/*
	KiFi, KDE Wireless Manager
	Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

	KiFi, (c) 2004 by the KiFi developers

	*************************************************************************
	*                                                                       *
	* This program is free software; you can redistribute it and/or modify  *
	* it under the terms of the GNU General Public License as published by  *
	* the Free Software Foundation; either version 2 of the License, or     *
	* (at your option) any later version.                                   *
	*                                                                       *
	*************************************************************************
	*/

#include "wirelessnetworkinfo.h"

#include <kdebug.h>

WirelessNetworkInfo::WirelessNetworkInfo()
	: _address(), _channel(), _freq(), _mode(), _nwid(), _nwidEnabled(),
		_signalStrength(), _ssid(), _supportedRates(), _wepRequired()
{
	// Nothing
}

WirelessNetworkInfo::WirelessNetworkInfo(
	QString & address, int channel, const QString &freq, QString &mode,
	int nwid, bool nwidEnabled, int signalStrength, QString & ssid,
	QStringList supportedRates, bool wepRequired )
	: _address( address ),
    _channel( channel ),
		_freq( freq ),
		_mode( mode ),
		_nwid( nwid ),
		_nwidEnabled( nwidEnabled ),
		_signalStrength( signalStrength ),
		_ssid( ssid ),
		_supportedRates( supportedRates ),
		_wepRequired( wepRequired )
{
	// Nothing
}

WirelessNetworkInfo::WirelessNetworkInfo( const WirelessNetworkInfo &oldInfo )
	: _address( oldInfo._address ),
    _channel( oldInfo._channel ),
		_freq( oldInfo._freq ),
		_mode( oldInfo._mode ),
		_nwid( oldInfo._nwid ),
		_nwidEnabled( oldInfo._nwidEnabled ),
		_signalStrength( oldInfo._signalStrength ),
		_ssid( oldInfo._ssid ),
		_supportedRates( oldInfo._supportedRates ),
		_wepRequired( oldInfo._wepRequired )
{
	// Nothing
}

WirelessNetworkInfo &WirelessNetworkInfo::operator=(
	const WirelessNetworkInfo &oldInfo )
{
	// Avoid self assignment
	if ( this != &oldInfo ) {
		_address = oldInfo._address;
    _channel = oldInfo._channel;
		_freq = oldInfo._freq;
		_mode = oldInfo._mode;
		_nwid = oldInfo._nwid;
		_nwidEnabled = oldInfo._nwidEnabled;
		_signalStrength = oldInfo._signalStrength;
		_ssid = oldInfo._ssid;
		_supportedRates = oldInfo._supportedRates;
		_wepRequired = oldInfo._wepRequired;
	}

	return *this;
}

bool WirelessNetworkInfo::operator==(
	const WirelessNetworkInfo &otherInfo )
{
	// QUESTION: Do we need this method?
	if ( this == &otherInfo ) {
		return true;
	} else {
		bool retval = ( otherInfo._ssid == _ssid )
			&& ( otherInfo._address == _address )
			&& ( otherInfo._wepRequired == _wepRequired )
			&& ( otherInfo._signalStrength == _signalStrength );
		kdDebug() << "WirelessNetworkInfo::operator== returning" << retval
							<< endl;
		return retval;
	}
}

// bool WirelessNetworkInfo::operator!=(
// 	const WirelessNetworkInfo &otherInfo )
// {
// 	return !operator==( otherInfo );
// }

QString WirelessNetworkInfo::getSSID()
{
	return _ssid;
}

void WirelessNetworkInfo::setSSID(const QString &newSSID )
{
	_ssid = newSSID;
}

QString WirelessNetworkInfo::getAddress()
{
	return _address;
}

void WirelessNetworkInfo::setAddress(const QString &newAddress )
{
	_address = newAddress;
}

bool WirelessNetworkInfo::getWepRequired()
{
	return _wepRequired;
}

void WirelessNetworkInfo::setWepRequired( bool required )
{
	_wepRequired = required;
}

int WirelessNetworkInfo::getSignalStrength()
{
	return _signalStrength;
}

void WirelessNetworkInfo::setSignalStrength( int newQuality )
{
	_signalStrength = newQuality;
}

bool WirelessNetworkInfo::getNWIDEnabled()
{
	return _nwidEnabled;
}

void WirelessNetworkInfo::setNWIDEnabled(bool flag)
{
	_nwid = flag;
}

QString WirelessNetworkInfo::getFrequency()
{
	return _freq;
}

void WirelessNetworkInfo::setFrequency(const QString &newFreq)
{
	_freq = newFreq;
}

int WirelessNetworkInfo::getChannel()
{
	return _channel;
}

void WirelessNetworkInfo::setChannel(int newChannel)
{
	_channel = newChannel;
}

int WirelessNetworkInfo::getNWID()
{
	return _nwid;
}

void WirelessNetworkInfo::setNWID( int newNwid )
{
	_nwid = newNwid;
}

QString WirelessNetworkInfo::getMode()
{
	return _mode;
}

void WirelessNetworkInfo::setMode( QString newMode )
{
	_mode = newMode;
}

QStringList WirelessNetworkInfo::getSupportedRates()
{
	return _supportedRates;
}

void WirelessNetworkInfo::addSupportedRate( QString newRate )
{
	_supportedRates.append( newRate );
}

void WirelessNetworkInfo::setSupportedRates( QStringList newRates )
{
	_supportedRates = newRates;
}

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
