/*
	KiFi, KDE Wireless Manager
	Copyright (c) 2002-2004 by Chris TenHarmsel <chris@staticmethod.net>

	KiFi, (c) 2004 by the KiFi developers

	*************************************************************************
	*                                                                       *
	* This program is free software; you can redistribute it and/or modify  *
	* it under the terms of the GNU General Public License as published by  *
	* the Free Software Foundation; either version 2 of the License, or     *
	* (at your option) any later version.                                   *
	*                                                                       *
	*************************************************************************
	*/

#ifndef _WIRELESSNETWORKSCANNER_H_
#define _WIRELESSNETWORKSCANNER_H_

extern "C"{
// Private copy....
#include <iwlib.h>
}

#include "wirelessnetworkinfo.h"

#include <qobject.h>
#include <qmap.h>

class QTimer;

/**
 * This class is responsible for collecting data on available wireless
 * networks.  It provides available data on each network that it finds.
 * @author Chris TenHarmsel <chris@staticmethod.net>
 */

class WirelessNetworkScanner : public QObject {
	Q_OBJECT

public:
	/** Constructor */
	WirelessNetworkScanner(QString &iface, QObject *parent = 0,
												 const char *name = 0);
	/** Desctructor */
	virtual ~WirelessNetworkScanner();

	/**
	 * This method will set the scanning interval
	 *
	 * @param msec The number of milliseconds between scans, cannot be
	 * less than 200ms
	 */
	void setUpdateInterval( int msec );

	/**
	 * This method will begin scanning for wireless networks.  Once this
	 * method has returned, the WirelessNetworkScanner will be in scan
	 * mode and will emit signals based on what it finds.  To stop it
	 * from scanning, call the stopScanning() method.
	 */
	void startScanning();

	/**
	 * This method will stop the WirelessNetworkScanner from scanning
	 * for wireless networks
	 */
	void stopScanning();

	/**
	 * This method is only used for testing, it is a main loop that
	 * scans and sleeps
	 */
	void run();

signals:
	/** This signal indicates that a new network has been found */
	void networkFound( WirelessNetworkInfo & info );

	/** This signal indicates that a network has been updated */
	void networkUpdated( WirelessNetworkInfo & info );

	/** This signal indicates that a network has been lost */
	void networkLost( WirelessNetworkInfo & info );

protected slots:
	/** This method updates the network info by performing a scan */
	void updateInfo();

protected:
	QTimer *_timer;
	int _timerInterval;
	QString _interface;
	int _iwsocket;
	QMap <QString, WirelessNetworkInfo> _knownNetworks;
};

#endif

/*
 * Local variables:
 * c-indentation-style: k&r
 * c-basic-offset: 2
 * indent-tabs-mode: t
 * End:
 */
